@@ -3,7 +3,7 @@ set -ex
 
 
 #---
-#   MinGW cross compiling environment  (1.3)
+#   MinGW cross compiling environment  (1.4)
 #   =================================
 #
 #   http://www.profv.de/mingw_cross_env/
@@ -51,6 +51,7 @@ set -ex
 #
 #   (c)  Volker Grabsch <vog@notjusthosting.com>
 #        Rocco Rutte <pdmef@gmx.net>
+#        Andreas Roever <roever@users.sf.net>
 #
 #   Permission is hereby granted, free of charge, to any person obtaining
 #   a copy of this software and associated documentation files (the
@@ -96,13 +97,13 @@ ROOT=`pwd`
 PREFIX="$ROOT/usr"
 SOURCE="$ROOT/src"
 DOWNLOAD="$ROOT/download"
-SOURCEFORGE_MIRROR=downloads.sourceforge.net
+SOURCEFORGE_MIRROR=kent.dl.sourceforge.net
 
 PATH="$PREFIX/bin:$PATH"
 
-VERSION_mingw_runtime=3.13
-VERSION_w32api=3.10
-VERSION_binutils=2.18.50-20071123
+VERSION_mingw_runtime=3.14
+VERSION_w32api=3.11
+VERSION_binutils=2.18.50-20080109
 VERSION_gcc=4.2.1-2
 VERSION_pkg_config=0.22
 VERSION_pthreads=2-8-0
@@ -125,7 +126,7 @@ VERSION_jpeg=6b
 VERSION_tiff=3.8.2
 VERSION_giflib=4.1.6
 VERSION_freetype=2.3.5
-VERSION_fontconfig=2.5.0
+VERSION_fontconfig=2.5.91
 VERSION_libmikmod=3.2.0-beta2
 VERSION_ogg=1.1.3
 VERSION_vorbis=1.2.0
@@ -135,12 +136,11 @@ VERSION_smpeg=0.4.5+cvs20030824
 VERSION_SDL_mixer=1.2.8
 VERSION_SDL_image=1.2.6
 VERSION_fltk=1.1.7
-VERSION_geos=3.0.0rc5
-VERSION_proj=4.5.0
+VERSION_geos=3.0.0
+VERSION_proj=4.6.0
 VERSION_libgeotiff=1.2.4
-VERSION_gdal=1.4.4
+VERSION_gdal=1.5.0
 VERSION_pdflib_lite=7.0.2
-VERSION_libowfat=0.26
 
 
 #---
@@ -161,20 +161,31 @@ case "$1" in
     sed -n 's/^#$\|^#   //p; /SOFTWARE\./ q' "$0" >README
     echo                    >>README
     echo                    >>README
-    echo "List of Packages" >>README
-    echo "================" >>README
+    echo 'Tutorial'         >>README
+    echo '========'         >>README
+    echo                    >>README
+    echo 'http://wiki.njh.eu/Win32_Cross_Compiling_Tutorial' \
+                            >>README
+    echo                    >>README
+    LC_ALL=C w3m -cols 65 -dump \
+         'http://wiki.njh.eu/Win32_Cross_Compiling_Tutorial' \
+    | sed -n '/^Making a Linux MinGW cross compiler$/,/^Hans Bezemer$/ p' \
+    | sed -n '3,$ p'        >>README
+    echo                    >>README
+    echo                    >>README
+    echo 'List of Packages' >>README
+    echo '================' >>README
     echo                    >>README
     awk <"$0" '
         BEGIN      { FS="^VERSION_|=" }
-        /^VERSION/ { printf "%-13s  %s\n", $2, $3 }' |
-    sort >>README
+        /^VERSION/ { printf "%-13s  %s\n", $2, $3 }' \
+    | sort >>README
     hg log -v --style changelog >ChangeLog
     VERSION=`$SED -n 's/.*(\([a-z0-9.-]*\))$/\1/p' "$0" | head -1`
     test -n "$VERSION"
     rm -rf "mingw_cross_env-$VERSION"
     mkdir  "mingw_cross_env-$VERSION"
     cp "$0" README ChangeLog "mingw_cross_env-$VERSION/"
-    cp fontconfig-2.5.0-crosscompile.patch "mingw_cross_env-$VERSION/"
     tar cfv - "mingw_cross_env-$VERSION" | gzip -9 >"mingw_cross_env-$VERSION.tar.gz"
     rm -rf "mingw_cross_env-$VERSION"
     exit 0
@@ -350,7 +361,7 @@ case "$1" in
 --new-versions)
     VERSION=`
         wget -q -O- 'http://sourceforge.net/project/showfiles.php?group_id=2435' |
-        $SED -n 's,.*gcc-\([0-9][^>]*\)-src\.tar.*,\1,p' | 
+        $SED -n 's,.*gcc-\([4-9][^>]*\)-src\.tar.*,\1,p' | 
         head -1`
     test -n "$VERSION"
     $SED "s,^VERSION_gcc=.*,VERSION_gcc=$VERSION," -i "$0"
@@ -1326,11 +1337,11 @@ case "$1" in
     cd "$SOURCE"
     tar xfvz "$DOWNLOAD/fontconfig-$VERSION_fontconfig.tar.gz"
     cd "fontconfig-$VERSION_fontconfig"
-    # apply a portability patch
-    patch -p1 <"$ROOT/fontconfig-2.5.0-crosscompile.patch"
     # ensure there is no (buggy) attempt to install the *.dll.a file
     # (remove this line of you want to link dynamically)
     $SED 's,^install-data-local:.*,install-data-local:,' -i src/Makefile.in
+    # wine confuses the cross-compiling detection, so set it explicitly
+    $SED 's,cross_compiling=no,cross_compiling=yes,' -i configure
     ./configure \
         --host="$TARGET" \
         --disable-shared \
@@ -1742,6 +1753,7 @@ case "$1" in
         --prefix="$PREFIX/$TARGET" \
         --enable-threads \
         LIBS="-lws2_32"
+    $SED 's,-fno-exceptions,,' -i makeinclude        
     $MAKE install DIRS=src
     cd "$SOURCE"
     rm -rfv "fltk-$VERSION_fltk"
@@ -1917,6 +1929,7 @@ case "$1" in
         --with-gif="$PREFIX/$TARGET" \
         --with-curl="$PREFIX/$TARGET/bin/curl-config" \
         --with-geos="$PREFIX/$TARGET/bin/geos-config" \
+        --with-expat=no \
         --without-python \
         --without-ngpython
     $MAKE lib-target
@@ -1988,52 +2001,6 @@ case "$1" in
 esac
 
 
-#---
-#   libowfat
-#
-#   http://www.fefe.de/libowfat/
-#---
-
-case "$1" in
-
---new-versions)
-    VERSION=`
-        wget -q -O- 'http://www.fefe.de/libowfat/' |
-        $SED -n 's,.*libowfat-\([0-9][^>]*\)\.tar.*,\1,p' |
-        head -1`
-    test -n "$VERSION"
-    $SED "s,^VERSION_libowfat=.*,VERSION_libowfat=$VERSION," -i "$0"
-    ;;
-
---download)
-    cd "$DOWNLOAD"
-    tar tfj "libowfat-$VERSION_libowfat.tar.bz2" &>/dev/null ||
-    wget -c "http://dl.fefe.de/libowfat-$VERSION_libowfat.tar.bz2"
-    ;;
-
---build)
-    cd "$SOURCE"
-    tar xfvj "$DOWNLOAD/libowfat-$VERSION_libowfat.tar.bz2"
-    cd "libowfat-$VERSION_libowfat"
-    $SED 's,gcc -I\. -MM,$(CROSS)gcc -I. -MM,' -i GNUmakefile
-    $MAKE Makefile -f GNUmakefile \
-        CROSS="$TARGET-" \
-        prefix="$PREFIX/$TARGET" \
-        INCLUDEDIR="$PREFIX/$TARGET/include/libowfat" \
-        DIET=
-    $MAKE install \
-        CROSS="$TARGET-" \
-        prefix="$PREFIX/$TARGET" \
-        INCLUDEDIR="$PREFIX/$TARGET/include/libowfat" \
-        DIET=
-    $SED 's,#include_next <io.h>,#include <io.h>,' -i "$PREFIX/$TARGET/include/libowfat/io.h"
-    cd "$SOURCE"
-    rm -rfv "libowfat-$VERSION_libowfat"
-    ;;
-
-esac
-
-
 #---
 #   Cleanup
 #---
